[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --fast-version-control
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NAME](https://git-scm.com/docs/git-tag#_name)
    * [SYNOPSIS](https://git-scm.com/docs/git-tag#_synopsis)
    * [DESCRIPTION](https://git-scm.com/docs/git-tag#_description)
    * [OPTIONS](https://git-scm.com/docs/git-tag#_options)
    * [CONFIGURATION](https://git-scm.com/docs/git-tag#_configuration)
    * [DISCUSSION](https://git-scm.com/docs/git-tag#_discussion)
    * [DATE FORMATS](https://git-scm.com/docs/git-tag#_date_formats)
    * [FILES](https://git-scm.com/docs/git-tag#_files)
    * [CONFIGURATION](https://git-scm.com/docs/git-tag#_configuration_2)
    * [NOTES](https://git-scm.com/docs/git-tag#_notes)
    * [SEE ALSO](https://git-scm.com/docs/git-tag#_see_also)
    * [GIT](https://git-scm.com/docs/git-tag#_git)


[ English ▾](https://git-scm.com/docs/git-tag)
Localized versions of **git-tag** manual
  1. [English ](https://git-scm.com/docs/git-tag)
  2. [Français ](https://git-scm.com/docs/git-tag/fr)
  3. [Português (Brasil) ](https://git-scm.com/docs/git-tag/pt_BR)
  4. [українська мова ](https://git-scm.com/docs/git-tag/uk)
  5. [简体中文 ](https://git-scm.com/docs/git-tag/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git-tag)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git)
  * [ config ](https://git-scm.com/docs/git-config)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init)
  * [ clone ](https://git-scm.com/docs/git-clone)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ commit ](https://git-scm.com/docs/git-commit)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore)
  * [ reset ](https://git-scm.com/docs/git-reset)
  * [ rm ](https://git-scm.com/docs/git-rm)
  * [ mv ](https://git-scm.com/docs/git-mv)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree)


[ Latest version ▾ ](https://git-scm.com/docs/git-tag) git-tag last updated in 2.52.0
Changes in the **git-tag** manual
  1. 2.53.0 no changes
  2. [2.52.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-11-17_ ](https://git-scm.com/docs/git-tag/2.52.0)
  3. 2.46.1 → 2.51.2 no changes
  4. [2.46.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-07-29_ ](https://git-scm.com/docs/git-tag/2.46.0)
  5. 2.45.1 → 2.45.4 no changes
  6. [2.45.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git-tag/2.45.0)
  7. 2.44.1 → 2.44.4 no changes
  8. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/git-tag/2.44.0)
  9. 2.42.1 → 2.43.7 no changes
  10. [2.42.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-08-21_ ](https://git-scm.com/docs/git-tag/2.42.0)
  11. 2.41.1 → 2.41.3 no changes
  12. [2.41.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-06-01_ ](https://git-scm.com/docs/git-tag/2.41.0)
  13. 2.39.1 → 2.40.4 no changes
  14. [2.39.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-12_ ](https://git-scm.com/docs/git-tag/2.39.0)
  15. 2.35.1 → 2.38.5 no changes
  16. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git-tag/2.35.0)
  17. 2.31.1 → 2.34.8 no changes
  18. [2.31.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-03-15_ ](https://git-scm.com/docs/git-tag/2.31.0)
  19. 2.29.1 → 2.30.9 no changes
  20. [2.29.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-10-19_ ](https://git-scm.com/docs/git-tag/2.29.0)
  21. 2.27.1 → 2.28.1 no changes
  22. [2.27.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-06-01_ ](https://git-scm.com/docs/git-tag/2.27.0)
  23. 2.25.1 → 2.26.3 no changes
  24. [2.25.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-01-13_ ](https://git-scm.com/docs/git-tag/2.25.0)
  25. 2.23.1 → 2.24.4 no changes
  26. [2.23.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-16_ ](https://git-scm.com/docs/git-tag/2.23.0)
  27. 2.21.1 → 2.22.5 no changes
  28. [2.21.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-02-24_ ](https://git-scm.com/docs/git-tag/2.21.0)
  29. 2.19.3 → 2.20.5 no changes
  30. [2.19.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-11-21_ ](https://git-scm.com/docs/git-tag/2.19.2)
  31. 2.19.1 no changes
  32. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git-tag/2.19.0)
  33. 2.18.1 → 2.18.5 no changes
  34. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git-tag/2.18.0)
  35. 2.17.1 → 2.17.6 no changes
  36. [2.17.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-04-02_ ](https://git-scm.com/docs/git-tag/2.17.0)
  37. 2.15.4 → 2.16.6 no changes
  38. [2.14.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git-tag/2.14.6)
  39. [2.13.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-05-22_ ](https://git-scm.com/docs/git-tag/2.13.7)
  40. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git-tag/2.12.5)
  41. [2.11.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git-tag/2.11.4)
  42. [2.10.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git-tag/2.10.5)
  43. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git-tag/2.9.5)
  44. 2.8.6 no changes
  45. [2.7.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git-tag/2.7.6)
  46. [2.6.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git-tag/2.6.7)
  47. 2.5.6 no changes
  48. [2.4.12 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git-tag/2.4.12)
  49. 2.2.3 → 2.3.10 no changes
  50. [2.1.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git-tag/2.1.4)
  51. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git-tag/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git-tag#_name)NAME
git-tag - Create, list, delete or verify tags
##  [](https://git-scm.com/docs/git-tag#_synopsis)SYNOPSIS
```
git tag [-a | -s | -u _<key-id>_] [-f] [-m _<msg>_ | -F _<file>_] [-e]
	[(--trailer _<token>_[(=|:)_<value>_])…​]
	_<tagname>_ [_<commit>_ | _<object>_]
git tag -d _<tagname>_…​
git tag [-n[_<num>_]] -l [--contains _<commit>_] [--no-contains _<commit>_]
	[--points-at _<object>_] [--column[=_<options>_] | --no-column]
	[--create-reflog] [--sort=_<key>_] [--format=_<format>_]
	[--merged _<commit>_] [--no-merged _<commit>_] [_<pattern>_…​]
git tag -v [--format=_<format>_] _<tagname>_…​
```

##  [](https://git-scm.com/docs/git-tag#_description)DESCRIPTION
Add a tag reference in `refs/tags/`, unless `-d`/`-l`/`-v` is given to delete, list or verify tags.
Unless `-f` is given, the named tag must not yet exist.
If one of `-a`, `-s`, or `-u` _< key-id>_ is passed, the command creates a _tag_ object, and requires a tag message. Unless `-m` _< msg>_ or `-F` _< file>_ is given, an editor is started for the user to type in the tag message.
If `-m` _< msg>_ or `-F` _< file>_ or `--trailer` _< token>_[`=`_< value>_] is given and `-a`, `-s`, and `-u` _< key-id>_ are absent, `-a` is implied.
Otherwise, a tag reference that points directly at the given object (i.e., a lightweight tag) is created.
A cryptographically signed tag object will be created when `-s` or `-u` _< key-id>_ is used. The signing backend (GPG, X.509, SSH, etc.) is controlled by the `gpg.format` configuration variable, defaulting to OpenPGP. When `-u` _< key-id>_ is not used, the committer identity for the current user is used to find the key for signing. The configuration variable `gpg.program` is used to specify a custom signing binary.
Tag objects (created with `-a`, `-s`, or `-u`) are called "annotated" tags; they contain a creation date, the tagger name and e-mail, a tagging message, and an optional cryptographic signature. Whereas a "lightweight" tag is simply a name for an object (usually a commit object).
Annotated tags are meant for release while lightweight tags are meant for private or temporary object labels. For this reason, some git commands for naming objects (like `git` `describe`) will ignore lightweight tags by default.
##  [](https://git-scm.com/docs/git-tag#_options)OPTIONS

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--a)`-a`


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---annotate)`--annotate`

Make an unsigned, annotated tag object

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--s)`-s`


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---sign)`--sign`

Make a cryptographically signed tag, using the default signing key. The signing backend used depends on the `gpg.format` configuration variable. The default key is determined by the backend. For GPG, it’s based on the committer’s email address, while for SSH it may be a specific key file or agent identity. See [git-config[1]](https://git-scm.com/docs/git-config).

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---no-sign)`--no-sign`

Override `tag.gpgSign` configuration variable that is set to force each and every tag to be signed.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--ukey-id)`-u` _< key-id>_


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---local-userkey-id)`--local-user=`_< key-id>_

Make a cryptographically signed tag using the given key. The format of the <key-id> and the backend used depend on the `gpg.format` configuration variable. See [git-config[1]](https://git-scm.com/docs/git-config).

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--f)`-f`


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---force)`--force`

Replace an existing tag with the given name (instead of failing)

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--d)`-d`


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---delete)`--delete`

Delete existing tags with the given names.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--v)`-v`


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---verify)`--verify`

Verify the cryptographic signature of the given tags.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--nnum)`-n`_< num>_

_< num>_ specifies how many lines from the annotation, if any, are printed when using `-l`. Implies `--list`.
The default is not to print any annotation lines. If no number is given to `-n`, only the first line is printed. If the tag is not annotated, the commit message is displayed instead.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--l)`-l`


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---list)`--list`

List tags. With optional _< pattern>_..., e.g. `git` `tag` `--list` `v-*'`, list only the tags that match the pattern(s).
Running `git` `tag` without arguments also lists all tags. The pattern is a shell wildcard (i.e., matched using `fnmatch`(3)). Multiple patterns may be given; if any of them matches, the tag is shown.
This option is implicitly supplied if any other list-like option such as `--contains` is provided. See the documentation for each of those options for details.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---sortkey)`--sort=`_< key>_

Sort based on the key given. Prefix `-` to sort in descending order of the value. You may use the `--sort=`_< key>_ option multiple times, in which case the last _< key>_ becomes the primary key. Also supports "`version:refname`" or "`v:refname`" (tag names are treated as versions). The "`version:refname`" sort order can also be affected by the "`versionsort.suffix`" configuration variable. The keys supported are the same as those in `git` `for-each-ref`. Sort order defaults to the value configured for the `tag.sort` variable if it exists, or lexicographic order otherwise. See [git-config[1]](https://git-scm.com/docs/git-config).

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---colorwhen)`--color`[`=`_< when>_]

Respect any colors specified in the `--format` option. The _< when>_ field must be one of `always`, `never`, or `auto` (if _< when>_ is absent, behave as if `always` was given).

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--i)`-i`


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---ignore-case)`--ignore-case`

Sorting and filtering tags are case insensitive.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---omit-empty)`--omit-empty`

Do not print a newline after formatted refs where the format expands to the empty string.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---columnoptions)`--column`[`=`_< options>_]


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---no-column)`--no-column`

Display tag listing in columns. See configuration variable `column.tag` for option syntax. `--column` and `--no-column` without options are equivalent to `always` and `never` respectively.
This option is only applicable when listing tags without annotation lines.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---containscommit)`--contains` [_< commit>_]

Only list tags which contain _< commit>_ (`HEAD` if not specified). Implies `--list`.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---no-containscommit)`--no-contains` [_< commit>_]

Only list tags which don’t contain _< commit>_ (`HEAD` if not specified). Implies `--list`.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---mergedcommit)`--merged` [_< commit>_]

Only list tags whose commits are reachable from _< commit>_ (`HEAD` if not specified).

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---no-mergedcommit)`--no-merged` [_< commit>_]

Only list tags whose commits are not reachable from _< commit>_ (`HEAD` if not specified).

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---points-atobject)`--points-at` [_< object>_]

Only list tags of _< object>_ (`HEAD` if not specified). Implies `--list`.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--mmsg)`-m` _< msg>_


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---messagemsg)`--message=`_< msg>_

Use _< msg>_ (instead of prompting). If multiple `-m` options are given, their values are concatenated as separate paragraphs. Implies `-a` if none of `-a`, `-s`, or `-u` _< key-id>_ is given.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--Ffile)`-F` _< file>_


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---filefile)`--file=`_< file>_

Take the tag message from _< file>_. Use `-` to read the message from the standard input. Implies `-a` if none of `-a`, `-s`, or `-u` _< key-id>_ is given.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---trailertokenvalue)`--trailer` _< token>_[(`=`|`:`)_< value>_]

Specify a (_< token>_, _< value>_) pair that should be applied as a trailer. (e.g. `git` `tag` `--trailer` `"Custom-Key:` `value"` will add a "Custom-Key" trailer to the tag message.) The `trailer.*` configuration variables ([git-interpret-trailers[1]](https://git-scm.com/docs/git-interpret-trailers)) can be used to define if a duplicated trailer is omitted, where in the run of trailers each trailer would appear, and other details. The trailers can be extracted in `git` `tag` `--list`, using `--format="%`(`trailers`)`"` placeholder.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt--e)`-e`


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---edit)`--edit`

Let further edit the message taken from file with `-F` and command line with `-m`.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---cleanupmode)`--cleanup=`_< mode>_

Set how the tag message is cleaned up. The _< mode>_ can be one of `verbatim`, `whitespace` and `strip`. The `strip` mode is default. The `verbatim` mode does not change message at all, `whitespace` removes just leading/trailing whitespace lines and `strip` removes both whitespace and commentary.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---create-reflog)`--create-reflog`

Create a reflog for the tag. To globally enable reflogs for tags, see `core.logAllRefUpdates` in [git-config[1]](https://git-scm.com/docs/git-config). The negated form `--no-create-reflog` only overrides an earlier `--create-reflog`, but currently does not negate the setting of `core.logAllRefUpdates`.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---formatformat)`--format=`_< format>_

A string that interpolates `%`(`fieldname`) from a tag ref being shown and the object it points at. The format is the same as that of [git-for-each-ref[1]](https://git-scm.com/docs/git-for-each-ref). When unspecified, defaults to `%`(`refname:strip=2`).

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-tagname)_< tagname>_

The name of the tag to create, delete, or describe. The new tag name must pass all checks defined by [git-check-ref-format[1]](https://git-scm.com/docs/git-check-ref-format). Some of these checks may restrict the characters allowed in a tag name.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-commit)_< commit>_


[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-object)_< object>_

The object that the new tag will refer to, usually a commit. Defaults to `HEAD`.
##  [](https://git-scm.com/docs/git-tag#_configuration)CONFIGURATION
By default, `git` `tag` in sign-with-default mode (`-s`) will use your committer identity (of the form _Your Name <your@email.address>_) to find a key. If you want to use a different default key, you can specify it in the repository configuration as follows:
```
[user]
    signingKey = <key-id>
```

The signing backend can be chosen via the `gpg.format` configuration variable, which defaults to `openpgp`. See [git-config[1]](https://git-scm.com/docs/git-config) for a list of other supported formats.
The path to the program used for each signing backend can be specified with the `gpg.`_< format>_`.program` configuration variable. For the `openpgp` backend, `gpg.program` can be used as a synonym for `gpg.openpgp.program`. See [git-config[1]](https://git-scm.com/docs/git-config) for details.
`pager.tag` is only respected when listing tags, i.e., when `-l` is used or implied. The default is to use a pager.
See [git-config[1]](https://git-scm.com/docs/git-config) for more details and other configuration variables.
##  [](https://git-scm.com/docs/git-tag#_discussion)DISCUSSION
###  [](https://git-scm.com/docs/git-tag#_on_re_tagging)On Re-tagging
What should you do when you tag a wrong commit and you would want to re-tag?
If you never pushed anything out, just re-tag it. Use `-f` to replace the old one. And you’re done.
But if you have pushed things out (or others could just read your repository directly), then others will have already seen the old tag. In that case you can do one of two things:
  1. The sane thing. Just admit you screwed up, and use a different name. Others have already seen one tag-name, and if you keep the same name, you may be in the situation that two people both have "version X", but they actually have _different_ "X"'s. So just call it "X.1" and be done with it.
  2. The insane thing. You really want to call the new version "X" too, _even though_ others have already seen the old one. So just use `git` `tag` `-f` again, as if you hadn’t already published the old one.


However, Git does **not** (and it should not) change tags behind users back. So if somebody already got the old tag, doing a `git` `pull` on your tree shouldn’t just make them overwrite the old one.
If somebody got a release tag from you, you cannot just change the tag for them by updating your own one. This is a big security issue, in that people MUST be able to trust their tag-names. If you really want to do the insane thing, you need to just fess up to it, and tell people that you messed up. You can do that by making a very public announcement saying:
```
Ok, I messed up, and I pushed out an earlier version tagged as X. I
then fixed something, and retagged the *fixed* tree as X again.

If you got the wrong tag, and want the new one, please delete
the old one and fetch the new one by doing:

	git tag -d X
	git fetch origin tag X

to get my updated tag.

You can test which tag you have by doing

	git rev-parse X

which should return 0123456789abcdef.. if you have the new version.

Sorry for the inconvenience.
```

Does this seem a bit complicated? It **should** be. There is no way that it would be correct to just "fix" it automatically. People need to know that their tags might have been changed.
###  [](https://git-scm.com/docs/git-tag#_on_automatic_following)On Automatic following
If you are following somebody else’s tree, you are most likely using remote-tracking branches (eg. `refs/remotes/origin/master`). You usually want the tags from the other end.
On the other hand, if you are fetching because you would want a one-shot merge from somebody else, you typically do not want to get tags from there. This happens more often for people near the toplevel but not limited to them. Mere mortals when pulling from each other do not necessarily want to automatically get private anchor point tags from the other person.
Often, "please pull" messages on the mailing list just provide two pieces of information: a repo URL and a branch name; this is designed to be easily cut&pasted at the end of a `git` `fetch` command line:
```
Linus, please pull from

	git://git..../proj.git master

to get the following updates...
```

becomes:
```
$ git pull git://git..../proj.git master
```

In such a case, you do not want to automatically follow the other person’s tags.
One important aspect of Git is its distributed nature, which largely means there is no inherent "upstream" or "downstream" in the system. On the face of it, the above example might seem to indicate that the tag namespace is owned by the upper echelon of people and that tags only flow downwards, but that is not the case. It only shows that the usage pattern determines who are interested in whose tags.
A one-shot pull is a sign that a commit history is now crossing the boundary between one circle of people (e.g. "people who are primarily interested in the networking part of the kernel") who may have their own set of tags (e.g. "this is the third release candidate from the networking group to be proposed for general consumption with 2.6.21 release") to another circle of people (e.g. "people who integrate various subsystem improvements"). The latter are usually not interested in the detailed tags used internally in the former group (that is what "internal" means). That is why it is desirable not to follow tags automatically in this case.
It may well be that among networking people, they may want to exchange the tags internal to their group, but in that workflow they are most likely tracking each other’s progress by having remote-tracking branches. Again, the heuristic to automatically follow such tags is a good thing.
###  [](https://git-scm.com/docs/git-tag#_on_backdating_tags)On Backdating Tags
If you have imported some changes from another VCS and would like to add tags for major releases of your work, it is useful to be able to specify the date to embed inside of the tag object; such data in the tag object affects, for example, the ordering of tags in the gitweb interface.
To set the date used in future tag objects, set the environment variable GIT_COMMITTER_DATE (see the later discussion of possible values; the most common form is "YYYY-MM-DD HH:MM").
For example:
```
$ GIT_COMMITTER_DATE="2006-10-02 10:31" git tag -s v1.0.1
```

##  [](https://git-scm.com/docs/git-tag#_date_formats)DATE FORMATS
The `GIT_AUTHOR_DATE` and `GIT_COMMITTER_DATE` environment variables support the following date formats:

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-Gitinternalformat)Git internal format

It is _< unix-timestamp>_ _< time-zone-offset>_, where _< unix-timestamp>_ is the number of seconds since the UNIX epoch. _< time-zone-offset>_ is a positive or negative offset from UTC. For example CET (which is 1 hour ahead of UTC) is `+0100`.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-RFC2822)RFC 2822

The standard date format as described by RFC 2822, for example `Thu,` `07` `Apr` `2005` `22:13:13` `+0200`.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-ISO8601)ISO 8601

Time and date specified by the ISO 8601 standard, for example `2005-04-07T22:13:13`. The parser accepts a space instead of the `T` character as well. Fractional parts of a second will be ignored, for example `2005-04-07T22:13:13.019` will be treated as `2005-04-07T22:13:13`.
Note |  In addition, the date part is accepted in the following formats: `YYYY.MM.DD`, `MM/DD/YYYY` and `DD.MM.YYYY`.
---|---
##  [](https://git-scm.com/docs/git-tag#_files)FILES

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-GITDIRTAGEDITMSG)`$GIT_DIR/TAG_EDITMSG`

This file contains the message of an in-progress annotated tag. If `git` `tag` exits due to an error before creating an annotated tag then the tag message that has been provided by the user in an editor session will be available in this file, but may be overwritten by the next invocation of `git` `tag`.
##  [](https://git-scm.com/docs/git-tag#_configuration_2)CONFIGURATION
Everything below this line in this section is selectively included from the [git-config[1]](https://git-scm.com/docs/git-config) documentation. The content is the same as what’s found there:

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-tagforceSignAnnotated)`tag.forceSignAnnotated`

A boolean to specify whether annotated tags created should be GPG signed. If `--annotate` is specified on the command line, it takes precedence over this option.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-tagsort)`tag.sort`

This variable controls the sort ordering of tags when displayed by `git-tag`. Without the `--sort=`_< value>_ option provided, the value of this variable will be used as the default.

[](https://git-scm.com/docs/git-tag#Documentation/git-tag.txt-taggpgSign)`tag.gpgSign`

A boolean to specify whether all tags should be GPG signed. Use of this option when running in an automated script can result in a large number of tags being signed. It is therefore convenient to use an agent to avoid typing your GPG passphrase several times. Note that this option doesn’t affect tag signing behavior enabled by `-u` _< keyid>_ or `--local-user=`_< keyid>_ options.
##  [](https://git-scm.com/docs/git-tag#_notes)NOTES
When combining multiple `--contains` and `--no-contains` filters, only references that contain at least one of the `--contains` commits and contain none of the `--no-contains` commits are shown.
When combining multiple `--merged` and `--no-merged` filters, only references that are reachable from at least one of the `--merged` commits and from none of the `--no-merged` commits are shown.
##  [](https://git-scm.com/docs/git-tag#_see_also)SEE ALSO
[git-check-ref-format[1]](https://git-scm.com/docs/git-check-ref-format). [git-config[1]](https://git-scm.com/docs/git-config).
##  [](https://git-scm.com/docs/git-tag#_git)GIT
Part of the [git[1]](https://git-scm.com/docs/git) suite
### tag
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
